Skip to contents

Extension of expression dataset at transcript-level

Super class

nexodiff::ExprData -> ExprDataTranscript

Methods

Inherited methods


Method new()

Initialize ExprDataTranscript object

Usage

ExprDataTranscript$new(
  design,
  annotation,
  with_fixed_length = FALSE,
  log_level = "WARN",
  suffix_pattern = "\\.\\d+$"
)

Arguments

design

A pairwise design object PairwiseDesign

annotation

An annotation object Annotation

with_fixed_length

A boolean indicating whether the NGS library is of a fixed length like 3 prime or not

log_level

Level of logging (see logging package). Default = WARN

suffix_pattern

See clean_txid_versions method Default = txid

Returns

A new ExprDataTranscript object.


Method clone()

The objects of this class are cloneable with this method.

Usage

ExprDataTranscript$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.