Skip to contents

A class representing DESeq2 results from a pairwise design.

Details

This class generates results from expression data associated with a pairwise design using the DESeq2 package.

This class inherits from the "PairwiseComp" class.

Super class

nexodiff::PairwiseComp -> PairwiseDESeq2

Methods

Inherited methods


Method new()

Initialize PairwiseDESeq2 object.

Usage

PairwiseDESeq2$new(
  expr_data,
  add_vars = c(),
  auto_filtering = TRUE,
  ncpus = 1,
  seed = 1234567,
  force_deseq2_norm = FALSE,
  shrinkage = NULL,
  min_base_mean = NULL,
  only_paired = FALSE,
  fit_formula = NULL
)

Arguments

expr_data

ExprData : expression data

add_vars

Character vactor with additional variable name in deisgn. Those given variable will be add to the analysis formula. However the fold-change in results will be the coefficient from the variable group

auto_filtering

whether or not to perform independent filtering.

ncpus

number of cpus to use for computation (default = 1)

seed

seed for random computation in DESeq2

force_deseq2_norm

renorm with deseq2 in place of internorm

shrinkage

The parameter for shrinkage type, if null, no shrinkage is applied. see DESeq2 documentation for shrinkage types.

min_base_mean

minimum value of base mean for filtering. Apply if not null and is priority before auto_filtering. default is null.

only_paired

Wether to apply a filtering to extract only the samples which are fully paired given the concatenated values in add_vars.

fit_formula

Character with the formula which must contains group.

Returns

A new PairWiseCompDESeq2 object.


Method clone()

The objects of this class are cloneable with this method.

Usage

PairwiseDESeq2$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.