Skip to contents

A class representing DESeq2 results from a pairwise design.

Details

This class generates results from expression data associated with a pairwise design using the dearseq package.

This class inherits from the "PairwiseComp" class.

Super class

nexodiff::PairwiseComp -> PairwiseDearseq

Methods

Inherited methods


Method new()

Initialize PairwiseDearseq object.

Usage

PairwiseDearseq$new(
  expr_data,
  add_vars = c(),
  auto_filtering = TRUE,
  ncpus = 1,
  seed = 1234567,
  force_deseq2_norm = FALSE
)

Arguments

expr_data

ExprData : expression data

add_vars

Character vactor with additional variable name in deisgn. Those given variable will be add to the analysis formula. However the fold-change in results will be the coefficient from the variable group

auto_filtering

whether or not to perform independent filtering.

ncpus

number of cpus to use for computation (default = 1)

seed

seed for random computation in Dearseq

force_deseq2_norm

renorm with deseq2 in place of internorm

Returns

A new PairWiseCompDESeq2 object.


Method clone()

The objects of this class are cloneable with this method.

Usage

PairwiseDearseq$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.