Skip to contents

This class generates raw Log Fold change without statistical inference or tests

Methods


Method new()

Initialize PairwiseLFC object.

Usage

PairwiseLFC$new(
  expr_data,
  ncpus = 1,
  method_ctrl = "ctrl_med",
  compute_chunk = NULL
)

Arguments

expr_data

ExprData : expression data

ncpus

number of cpus to use for computation (default = 1)

method_ctrl

method to compute the reference expression

  • ctrl_each : samples are compared to each ctrl

  • ctrl_med : samples are compared to the median of ctrl

  • ctrl_mean : samples are compared to the mean of ctrl

  • ctrl_geo : samples are compared to the geo mean of ctrl

  • ctrl_geo_mod : samples are compared to the modified geo mean of ctrl

compute_chunk

a vector of index to select the groups to compute this option is present to limit compution time.

Returns

A new PairwiseLFC object.


Method get_results()

Get LFC results

Usage

PairwiseLFC$get_results()

Returns

A nested dataframe.


Method clone()

The objects of this class are cloneable with this method.

Usage

PairwiseLFC$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.