Skip to contents

utils function for this class only scores min given for unique first and then for dups before merging switch to data.table

Usage

create_uniprot_gene_id_mappings(
  idmapping,
  unique_reviewed_min_score = 1L,
  dups_reviewed_min_score = 4L,
  unique_unreviewed_min_score = 2L,
  dups_unreviewed_min_score = 5L
)

Arguments

idmapping

data.table with id mappings from uniprot KB

annotation

data.table with annotation from gff files

reviewed_min_scores

vector of two integers with min scores for reviewed entries, first for unique and then for dups

unreviewed_min_scores

vector of two integers with min scores for unreviewed entries, first for unique and then for dups