Skip to contents

Generate a simple chord plot

Usage

simple_chord(
  data,
  superset_colname = "batch",
  set_colname = "group",
  data_colname = "data",
  data_list_colname = "gid",
  scale_groups = TRUE,
  isolate_supersets = TRUE
)

Arguments

data

a tibble data frame with nested gene list

superset_colname

name of the column with the superset code

set_colname

name of the column with the set code

data_colname

name of the column with the nested lists

data_list_colname

name of the subcolumn within the nested lists that hold the ids of interest.

scale_groups

whether to scale the sizes of groups on the graph

isolate_supersets

whether to isolate the sets within the same superset