A class representing DESeq2 results from a pairwise design.
Details
This class generates results from expression data associated with a pairwise design using the dearseq package.
This class inherits from the "PairwiseComp" class.
Super class
nexodiff::PairwiseComp -> PairwiseDearseq
Methods
Inherited methods
nexodiff::PairwiseComp$build_tag_hclust()nexodiff::PairwiseComp$cross_args_and_generate_lists()nexodiff::PairwiseComp$extract_data_for_plot()nexodiff::PairwiseComp$filter_and_get_results()nexodiff::PairwiseComp$generate_a_list()nexodiff::PairwiseComp$generate_summary()nexodiff::PairwiseComp$get_results()nexodiff::PairwiseComp$plot_de()nexodiff::PairwiseComp$plot_heatmap()nexodiff::PairwiseComp$plot_lfc_per_group()nexodiff::PairwiseComp$plot_lfc_per_group_facet_tags()nexodiff::PairwiseComp$plot_ma()nexodiff::PairwiseComp$plot_summary()nexodiff::PairwiseComp$plot_vulcano()nexodiff::PairwiseComp$write_to_xlsx()
Method new()
Initialize PairwiseDearseq object.
Usage
PairwiseDearseq$new(
expr_data,
add_vars = c(),
auto_filtering = TRUE,
ncpus = 1,
seed = 1234567,
force_deseq2_norm = FALSE
)Arguments
expr_dataExprData : expression data
add_varsCharacter vactor with additional variable name in deisgn. Those given variable will be add to the analysis formula. However the fold-change in results will be the coefficient from the variable
groupauto_filteringwhether or not to perform independent filtering.
ncpusnumber of cpus to use for computation (default = 1)
seedseed for random computation in Dearseq
force_deseq2_normrenorm with deseq2 in place of internorm