Class representing raw Log Fold change results from a pairwaise design
Source:R/class_PairwiseLFC.r
PairwiseLFC.RdThis class generates raw Log Fold change without statistical inference or tests
Methods
Method new()
Initialize PairwiseLFC object.
Usage
PairwiseLFC$new(
expr_data,
ncpus = 1,
method_ctrl = "ctrl_med",
compute_chunk = NULL
)Arguments
expr_dataExprData : expression data
ncpusnumber of cpus to use for computation (default = 1)
method_ctrlmethod to compute the reference expression
ctrl_each: samples are compared to each ctrlctrl_med: samples are compared to the median of ctrlctrl_mean: samples are compared to the mean of ctrlctrl_geo: samples are compared to the geo mean of ctrlctrl_geo_mod: samples are compared to the modified geo mean of ctrl
compute_chunka vector of index to select the groups to compute this option is present to limit compution time.